Usage
divergence(h, count, window = NULL, filter = getCorFilter.RMT(), measure = 'information')
divergence.information(h, count, window, filter)
divergence.stability(h, count, window, filter)
divergence.kl(sigma.1, sigma.2)
divergenceLimit.kl(m, t = NULL)
stabilityLimit.kl(m, t = NULL)
plotDivergenceLimit.kl(m, t.range, ..., overlay = FALSE)
Arguments
h
A zoo object representing a portfolio with dimensions T x M
count
The number of bootstrap observations to create
window
The number of samples to include in each observation. Defaults to the anylength of h.
filter
The correlation filter to measure
measure
The type of divergence to calculate. Possible choices are information (default) or stability.
sigma.1
The sample correlation matrix
sigma.2
The model correlation matrix (aka the filtered matrix)
t
The number of samples (dates) in an observation
t.range
A range of date samples. This can be a simple interval so long as it matches the number of samples per asset in the measured correlation matrix.
overlay
Overlay the divergence limit plot on an existing plot. Default is FALSE.
...
Additional parameters to pass to plot or lines