Learn R Programming

tawny (version 2.0.2)

sp500.subset: A subset of the SP500 with 200 data points

Description

This data set provides a subset of the SP500 with returns suitable for running against the portfolio optimization routines.

Usage

sp500.subset

Arguments

format

A 200x75 zoo object of asset returns

source

Yahoo! Finance